@@ -6,12 +6,12 @@
 #
 # Cross toolchain and NSIS for Linux/i386 can be fetched from
 #  http://www.ch-werner.de/xtools/cross-mingw32-3.1-4.i386.rpm
-#  http://www.ch-werner.de/xtools/nsis-2.11-1.i386.rpm
+#  http://www.ch-werner.de/xtools/nsis-2.37-1.i386.rpm
 
 set -e
 
 VER2=2.8.17
-VER3=3.6.10
+VER3=3.7.2
 TCCVER=0.9.24
 
 if test -n "$SQLITE_DLLS" ; then
@@ -36,7 +36,7 @@ ln -sf sqlite-${VER2} sqlite
 
 # enable sqlite_encode_binary et.al.
 patch sqlite/main.mk <<'EOD'
---- sqlite/main.mk.orig	2005-04-24 00:43:23.000000000 +0200
+--- sqlite.orig/main.mk	2005-04-24 00:43:23.000000000 +0200
 +++ sqlite/main.mk	2006-03-16 14:29:55.000000000 +0100
 @@ -55,7 +55,7 @@
  # Object files for the SQLite library.
@@ -48,9 +48,10 @@ patch sqlite/main.mk <<'EOD'
           select.o table.o tokenize.o trigger.o update.o util.o \
           vacuum.o vdbe.o vdbeaux.o where.o tclsqlite.o
 EOD
+
 # display encoding
 patch sqlite/src/shell.c <<'EOD'
---- sqlite/src/shell.c.orig	2005-04-24 00:43:22.000000000 +0200
+--- sqlite.orig/src/shell.c	2005-04-24 00:43:22.000000000 +0200
 +++ sqlite/src/shell.c	2006-05-23 08:22:01.000000000 +0200
 @@ -1180,6 +1180,7 @@
    "   -separator 'x'       set output field separator (|)\n"
@@ -85,10 +86,11 @@ patch sqlite/src/shell.c <<'EOD'
        zHome = find_home_dir();
        if( zHome && (zHistory = malloc(strlen(zHome)+20))!=0 ){
 EOD
+
 # use open file dialog when no database name given
 # need to link with -lcomdlg32 when enabled
 true || patch sqlite/src/shell.c <<'EOD'
---- sqlite/src/shell.c.orig        2006-07-23 11:18:13.000000000 +0200
+--- sqlite.orig/src/shell.c        2006-07-23 11:18:13.000000000 +0200
 +++ sqlite/src/shell.c     2006-07-23 11:30:26.000000000 +0200
 @@ -20,6 +20,10 @@
  #include "sqlite.h"
@@ -123,7 +125,7 @@ EOD
 
 # same but new module libshell.c
 patch sqlite/main.mk <<'EOD'
---- sqlite/main.mk.orig        2007-01-10 19:30:52.000000000 +0100
+--- sqlite.orig/main.mk        2007-01-10 19:30:52.000000000 +0100
 +++ sqlite/main.mk     2007-01-10 19:33:39.000000000 +0100
 @@ -54,7 +54,7 @@
  
@@ -137,7 +139,7 @@ patch sqlite/main.mk <<'EOD'
 EOD
 cp -p sqlite/src/shell.c sqlite/src/libshell.c
 patch sqlite/src/libshell.c <<'EOD'
---- sqlite/src/libshell.c.orig  2007-01-10 19:13:01.000000000 +0100
+--- sqlite.orig/src/libshell.c  2007-01-10 19:13:01.000000000 +0100
 +++ sqlite/src/libshell.c  2007-01-10 19:25:56.000000000 +0100
 @@ -20,6 +20,10 @@
  #include "sqlite.h"
@@ -178,10 +180,11 @@ patch sqlite/src/libshell.c <<'EOD'
    }
    if( i<argc ){
 EOD
+
 rm -f sqlite/src/minshell.c
 touch sqlite/src/minshell.c
 patch sqlite/src/minshell.c <<'EOD'
---- sqlite/src/minshell.c.orig  2007-01-10 18:46:47.000000000 +0100
+--- sqlite.orig/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 +++ sqlite/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 @@ -0,0 +1,20 @@
 +/*
@@ -212,13 +215,21 @@ echo "====================="
 test -r sqlite-${VER3}.tar.gz || \
     wget -c http://www.sqlite.org/sqlite-${VER3}.tar.gz
 test -r sqlite-${VER3}.tar.gz || exit 1
+test -r extension-functions.c ||
+    wget -O extension-functions.c -c \
+      'http://www.sqlite.org/contrib/download/extension-functions.c?get=25'
+if test -r extension-functions.c ; then
+  cp extension-functions.c extfunc.c
+  patch < extfunc.patch
+fi
+test -r extfunc.c || exit 1
 
 rm -f sqlite3
 tar xzf sqlite-${VER3}.tar.gz
 ln -sf sqlite-${VER3} sqlite3
 
 patch sqlite3/main.mk <<'EOD'
---- sqlite3/main.mk.orig        2007-03-31 14:32:21.000000000 +0200
+--- sqlite3.orig/main.mk        2007-03-31 14:32:21.000000000 +0200
 +++ sqlite3/main.mk     2007-04-02 11:04:50.000000000 +0200
 @@ -67,7 +67,7 @@
 
@@ -230,10 +241,11 @@ patch sqlite3/main.mk <<'EOD'
    $(TOP)/src/analyze.c \
    $(TOP)/src/attach.c \
 EOD
+
 # use open file dialog when no database name given
 # need to link with -lcomdlg32 when enabled
 true || patch sqlite3/src/shell.c <<'EOD'
---- sqlite3/src/shell.c.orig        2006-06-06 14:32:21.000000000 +0200
+--- sqlite3.orig/src/shell.c        2006-06-06 14:32:21.000000000 +0200
 +++ sqlite3/src/shell.c     2006-07-23 11:04:50.000000000 +0200
 @@ -21,6 +21,10 @@
  #include <ctype.h>
@@ -267,7 +279,7 @@ true || patch sqlite3/src/shell.c <<'EOD'
 EOD
 # SQLite 3.5.1 Win32 mutex fix
 test "$VER3" != "3.5.1" || patch sqlite3/src/mutex_w32.c <<'EOD'
---- sqlite3/src/mutex_w32.c.orig	2007-08-30 14:10:30
+--- sqlite3.orig/src/mutex_w32.c	2007-08-30 14:10:30
 +++ sqlite3/src/mutex_w32.c	2007-09-04 22:31:3
 @@ -141,6 +141,12 @@
    p->nRef++;
@@ -296,7 +308,7 @@ EOD
 # same but new module libshell.c
 cp -p sqlite3/src/shell.c sqlite3/src/libshell.c
 patch sqlite3/src/libshell.c <<'EOD'
---- sqlite3/src/libshell.c.orig  2007-01-08 23:40:05.000000000 +0100
+--- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
 @@ -21,6 +21,10 @@
  #include <ctype.h>
@@ -337,10 +349,11 @@ patch sqlite3/src/libshell.c <<'EOD'
      data.zDbFilename = ":memory:";
  #else
 EOD
+
 rm -f sqlite3/src/minshell.c
 touch sqlite3/src/minshell.c
 patch sqlite3/src/minshell.c <<'EOD'
---- sqlite3/src/minshell.c.orig  2007-01-10 18:46:47.000000000 +0100
+--- sqlite3.orig/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 +++ sqlite3/src/minshell.c  2007-01-10 18:46:47.000000000 +0100
 @@ -0,0 +1,20 @@
 +/*
@@ -392,7 +405,12 @@ test "$VER3" = "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlite
 EOD
 
 # patch: parse foreign key constraints on virtual tables
-patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
+  -a "$VER3" != "3.6.18" -a "$VER3" != "3.6.19" -a "$VER3" != "3.6.20" \
+  -a "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
+  -a "$VER3" != "3.6.23.1" -a "$VER3" != "3.7.0" -a "$VER3" != "3.7.0.1" \
+  -a "$VER3" != "3.7.1" -a "$VER3" != "3.7.2" \
+  && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
 +++ sqlite3/src/build.c	2007-01-30 08:14:41.000000000 +0100
@@ -421,7 +439,7 @@ diff -u sqlite3.orig/src/pragma.c sqlite3/src/pragma.c
 diff -u sqlite3.orig/src/vtab.c sqlite3/src/vtab.c
 --- sqlite3.orig/src/vtab.c	2007-01-09 15:01:14.000000000 +0100
 +++ sqlite3/src/vtab.c	2007-01-30 08:23:22.000000000 +0100
-@@ -436,6 +436,9 @@
+@@ -540,6 +540,9 @@
    int rc = SQLITE_OK;
    Table *pTab = db->pVTab;
    char *zErr = 0;
@@ -429,9 +447,9 @@ diff -u sqlite3.orig/src/vtab.c sqlite3/src/vtab.c
 +  FKey *pFKey;
 +#endif
  
-   if( !pTab ){
-     sqlite3Error(db, SQLITE_MISUSE, 0);
-@@ -464,6 +467,15 @@
+   sqlite3_mutex_enter(db->mutex);
+   pTab = db->pVTab;
+@@ -568,6 +571,15 @@
    }
    sParse.declareVtab = 0;
  
@@ -444,9 +462,9 @@ diff -u sqlite3.orig/src/vtab.c sqlite3/src/vtab.c
 +  }
 +#endif
 +
-   sqlite3_finalize((sqlite3_stmt*)sParse.pVdbe);
-   sqlite3DeleteTable(0, sParse.pNewTable);
-   sParse.pNewTable = 0;
+   if( sParse.pVdbe ){
+     sqlite3VdbeFinalize(sParse.pVdbe);
+   }
 EOD
 
 # patch: re-enable NO_TCL in tclsqlite.c (3.3.15)
@@ -456,7 +474,7 @@ diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw-cross-build.sh,v 1.38 2009/01/27 09:00:03 chw Exp chw $
+ ** $Id: mingw-cross-build.sh,v 1.51 2010/08/24 13:25:30 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -513,8 +531,9 @@ true || patch -d sqlite3 -p1 <<'EOD'
    }
    if( type>=RESERVED_LOCK ){
 EOD
-# patch: Win32 locking and pager unlock, for SQLite3 >= 3.5.4
-patch -d sqlite3 -p1 <<'EOD'
+
+# patch: Win32 locking and pager unlock, for SQLite3 >= 3.5.4 && <= 3.6.10
+true || patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/os_win.c       2007-12-13 22:38:58.000000000 +0100
 +++ sqlite3/src/os_win.c    2008-01-18 10:01:48.000000000 +0100
 @@ -855,8 +855,8 @@
@@ -558,8 +577,54 @@ patch -d sqlite3 -p1 <<'EOD'
    if( type>=RESERVED_LOCK ){
 EOD
 
+# patch: Win32 locking and pager unlock, for SQLite3 >= 3.6.11 && < 3.7.0
+true || patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/src/os_win.c    2009-02-15 14:07:09.000000000 +0100
++++ sqlite3/src/os_win.c    2009-02-20 16:39:48.000000000 +0100
+@@ -922,7 +922,7 @@
+   newLocktype = pFile->locktype;
+   if(   (pFile->locktype==NO_LOCK)
+      || (   (locktype==EXCLUSIVE_LOCK)
+-         && (pFile->locktype==RESERVED_LOCK))
++         && (pFile->locktype<RESERVED_LOCK))
+   ){
+     int cnt = 3;
+     while( cnt-->0 && (res = LockFile(pFile->h, PENDING_BYTE, 0, 1, 0))==0 ){
+@@ -981,7 +981,18 @@
+     }else{
+       error = GetLastError();
+       OSTRACE2("error-code = %d\n", error);
+-      getReadLock(pFile);
++      if( !getReadLock(pFile) ){
++        /* This should never happen.  We should always be able to
++        ** reacquire the read lock */
++        OSTRACE1("could not re-get a SHARED lock.\n");
++        if( newLocktype==PENDING_LOCK || pFile->locktype==PENDING_LOCK ){
++          UnlockFile(pFile->h, PENDING_BYTE, 0, 1, 0);
++        }
++        if( pFile->locktype==RESERVED_LOCK ){
++          UnlockFile(pFile->h, RESERVED_BYTE, 0, 1, 0);
++        }
++        newLocktype = NO_LOCK;
++      }
+     }
+   }
+ 
+@@ -1057,6 +1068,7 @@
+       /* This should never happen.  We should always be able to
+       ** reacquire the read lock */
+       rc = SQLITE_IOERR_UNLOCK;
++      locktype = NO_LOCK;
+     }
+   }
+   if( type>=RESERVED_LOCK ){
+EOD
+
 # patch: compile fix for FTS3 as extension module
-patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
+  -a "$VER3" != "3.6.23.1" -a "$VER3" != "3.7.0" -a "$VER3" != "3.7.0.1" \
+  -a "$VER3" != "3.7.1" -a "$VER3" != "3.7.2" \
+  && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
 @@ -274,10 +274,6 @@
@@ -582,6 +647,35 @@ patch -d sqlite3 -p1 <<'EOD'
  int sqlite3_extension_init(
    sqlite3 *db, 
    char **pzErrMsg,
+EOD
+test "$VER3" = "3.6.21" -o "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" \
+  -o "$VER3" = "3.6.23.1" -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
+  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
++++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
+@@ -274,10 +274,6 @@
+ 
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
+ 
+-#if defined(SQLITE_ENABLE_FTS3) && !defined(SQLITE_CORE)
+-# define SQLITE_CORE 1
+-#endif
+-
+ #include "fts3Int.h"
+
+ #include <assert.h>
+@@ -6389,7 +6385,7 @@
+   return rc;
+ }
+ 
+-#if !SQLITE_CORE
++#ifndef SQLITE_CORE
+ int sqlite3_extension_init(
+   sqlite3 *db, 
+   char **pzErrMsg,
+EOD
+patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_porter.c  2008-02-01 16:40:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_porter.c       2008-03-16 11:34:50.000000000 +0100
 @@ -31,6 +31,11 @@
@@ -623,9 +717,104 @@ patch -d sqlite3 -p1 <<'EOD'
 +
  #include "sqlite3.h"
  #include "fts3_hash.h"
+EOD
+test "$VER3" = "3.6.21" && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3_write.c   2009-12-03 20:39:06.000000000 +0100
++++ sqlite3/ext/fts3/fts3_write.c        2010-01-05 07:59:27.000000000 +0100
+@@ -20,6 +20,10 @@
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
  
---- sqlite3.orig/ext/fts3/fts3_tokenizer.c	2008-06-24 03:29:58.000000000 +0200
-+++ sqlite3/ext/fts3/fts3_tokenizer.c	2008-07-17 08:38:24.000000000 +0200
+ #include "fts3Int.h"
++#include "sqlite3ext.h"
++#ifndef SQLITE_CORE
++extern const sqlite3_api_routines *sqlite3_api;
++#endif
+ #include <string.h>
+ #include <assert.h>
+ #include <stdlib.h>
+EOD
+test "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" -o "$VER3" = "3.6.23.1" \
+  -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
+  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3_write.c   2010-01-05 09:42:19.000000000 +0100
++++ sqlite3/ext/fts3/fts3_write.c        2010-01-05 09:55:25.000000000 +0100
+@@ -20,6 +20,10 @@
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
+ 
+ #include "fts3Int.h"
++#include "sqlite3ext.h"
++#ifndef SQLITE_CORE
++extern const sqlite3_api_routines *sqlite3_api;
++#endif
+ #include <string.h>
+ #include <assert.h>
+ #include <stdlib.h>
+@@ -2226,7 +2230,7 @@
+ 
+   if( !zVal ){
+     return SQLITE_NOMEM;
+-  }else if( nVal==8 && 0==sqlite3_strnicmp(zVal, "optimize", 8) ){
++  }else if( nVal==8 && 0==strnicmp(zVal, "optimize", 8) ){
+     rc = fts3SegmentMerge(p, -1);
+     if( rc==SQLITE_DONE ){
+       rc = SQLITE_OK;
+@@ -2234,10 +2238,10 @@
+       sqlite3Fts3PendingTermsClear(p);
+     }
+ #ifdef SQLITE_TEST
+-  }else if( nVal>9 && 0==sqlite3_strnicmp(zVal, "nodesize=", 9) ){
++  }else if( nVal>9 && 0==strnicmp(zVal, "nodesize=", 9) ){
+     p->nNodeSize = atoi(&zVal[9]);
+     rc = SQLITE_OK;
+-  }else if( nVal>11 && 0==sqlite3_strnicmp(zVal, "maxpending=", 9) ){
++  }else if( nVal>11 && 0==strnicmp(zVal, "maxpending=", 9) ){
+     p->nMaxPendingData = atoi(&zVal[11]);
+     rc = SQLITE_OK;
+ #endif
+EOD
+test "$VER3" = "3.6.21" -o "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" \
+  -o "$VER3" = "3.6.23.1" -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
+  -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3_snippet.c 2009-12-03 12:33:32.000000000 +0100
++++ sqlite3/ext/fts3/fts3_snippet.c      2010-01-05 08:03:51.000000000 +0100
+@@ -14,6 +14,10 @@
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
+ 
+ #include "fts3Int.h"
++#include "sqlite3ext.h"
++#ifndef SQLITE_CORE
++extern const sqlite3_api_routines *sqlite3_api;
++#endif
+ #include <string.h>
+ #include <assert.h>
+ #include <ctype.h>
+--- sqlite3.orig/ext/fts3/fts3_expr.c    2009-12-03 12:33:32.000000000 +0100
++++ sqlite3/ext/fts3/fts3_expr.c 2010-01-05 08:06:10.000000000 +0100
+@@ -17,6 +17,11 @@
+ */
+ #if !defined(SQLITE_CORE) || defined(SQLITE_ENABLE_FTS3)
+ 
++#include "sqlite3ext.h"
++#ifndef SQLITE_CORE
++extern const sqlite3_api_routines *sqlite3_api;
++#endif
++
+ /*
+ ** By default, this module parses the legacy syntax that has been 
+ ** traditionally used by fts3. Or, if SQLITE_ENABLE_FTS3_PARENTHESIS
+@@ -445,7 +450,7 @@
+     const char *zStr = pParse->azCol[ii];
+     int nStr = (int)strlen(zStr);
+     if( nInput>nStr && zInput[nStr]==':' 
+-     && sqlite3_strnicmp(zStr, zInput, nStr)==0 
++     && memcmp(zStr, zInput, nStr)==0 
+     ){
+       iCol = ii;
+       iColLen = (int)((zInput - z) + nStr + 1);
+--- sqlite3.orig/ext/fts3/fts3_tokenizer.c       2009-12-07 17:38:46.000000000 +0100
++++ sqlite3/ext/fts3/fts3_tokenizer.c    2010-01-05 08:12:50.000000000 +0100
 @@ -27,7 +27,7 @@
  
  #include "sqlite3ext.h"
@@ -634,10 +823,24 @@ patch -d sqlite3 -p1 <<'EOD'
 +extern const sqlite3_api_routines *sqlite3_api;
  #endif
  
- #include "fts3_hash.h"
+ #include "fts3Int.h"
+@@ -166,7 +166,7 @@
+   if( !z ){
+     zCopy = sqlite3_mprintf("simple");
+   }else{
+-    if( sqlite3_strnicmp(z, "tokenize", 8) || fts3IsIdChar(z[8])){
++    if( strnicmp(z, "tokenize", 8) || fts3IsIdChar(z[8])){
+       return SQLITE_OK;
+     }
+     zCopy = sqlite3_mprintf("%s", &z[8]);
 EOD
+
 # patch: FTS3 again, for SQLite3 >= 3.6.8
-test "$VER3" == "3.6.8" -o "$VER3" = "3.6.9" -o "$VER3" = "3.6.10" && \
+test "$VER3" = "3.6.8" -o "$VER3" = "3.6.9" -o "$VER3" = "3.6.10" \
+  -o "$VER3" = "3.6.11" -o "$VER3" = "3.6.12" -o "$VER3" = "3.6.13" \
+  -o "$VER3" = "3.6.14" -o "$VER3" = "3.6.14.1" -o "$VER3" = "3.6.14.2" \
+  -o "$VER3" = "3.6.15" -o "$VER3" = "3.6.16" -o "$VER3" = "3.6.17" \
+  -o "$VER3" = "3.6.18" -o "$VER3" = "3.6.19" -o "$VER3" = "3.6.20" &&
   patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2009-01-01 15:06:13.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_expr.c	2009-01-14 09:55:13.000000000 +0100
@@ -655,6 +858,20 @@ test "$VER3" == "3.6.8" -o "$VER3" = "3.6.9" -o "$VER3" = "3.6.10" && \
  #include <ctype.h>
  #include <string.h>
 EOD
+test "$VER3" = "3.6.17" -o "$VER3" = "3.6.18" -o "$VER3" = "3.6.19" \
+  -o "$VER3" = "3.6.20" && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3_expr.c   2009-01-01 15:06:13.000000000 +0100
++++ sqlite3/ext/fts3/fts3_expr.c        2009-01-14 09:55:13.000000000 +0100
+@@ -428,7 +428,7 @@
+     const char *zStr = pParse->azCol[ii];
+     int nStr = strlen(zStr);
+     if( nInput>nStr && zInput[nStr]==':' 
+-     && sqlite3_strnicmp(zStr, zInput, nStr)==0 
++     && memcmp(zStr, zInput, nStr)==0 
+     ){
+       iCol = ii;
+       iColLen = ((zInput - z) + nStr + 1);
+EOD
 # patch: compile fix for rtree as extension module
 patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
@@ -690,6 +907,7 @@ make -C sqlite -f ../mf-sqlite.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3fts.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3rtree.mingw-cross clean
+make -f mf-sqlite3extfunc.mingw-cross clean
 
 echo "============================="
 echo "Building SQLite 2 ... ISO8859"
@@ -751,6 +969,11 @@ echo "====================================="
 make -C sqlite3 -f ../mf-sqlite3rtree.mingw-cross clean all
 mv sqlite3/sqlite3_mod_rtree.dll .
 
+echo "========================================"
+echo "Building SQLite3 extension functions ..."
+echo "========================================"
+make -f mf-sqlite3extfunc.mingw-cross clean all
+
 echo "============================"
 echo "Building DLL import defs ..."
 echo "============================"
@@ -783,6 +1006,7 @@ rm -f sqlite3/sqlite3.exe
 make -C sqlite3 -f ../mf-sqlite3fts.mingw-cross clean
 make -C sqlite3 -f ../mf-sqlite3rtree.mingw-cross clean
 mv sqlite3/sqlite3.amalg sqlite3/sqlite3.c
+make -f mf-sqlite3extfunc.mingw-cross semiclean
 
 echo "==========================="
 echo "Creating NSIS installer ..."
